getTableByName method

TableCache? getTableByName(
  1. String tableName
)

Get a table cache by name without enforcing a type parameter.

Returns null if no decoder is registered for tableName.

Implementation

TableCache? getTableByName(String tableName) => _tables[tableName];