MutationSyncer class

Implemented types

Constructors

MutationSyncer({required SpacetimeDbConnection connection, required OfflineStorage storage, required OptimisticStateManager optimisticState, required ClientCache cache, required SendReducer send, OfflineQueuePolicy policy = const OfflineQueuePolicy()})

Properties

hashCode int
The hash code for this object.
no setterinherited
isSyncing bool
no setter
onMutationSyncResult Stream<MutationSyncResult>
no setter
onSyncStateChanged Stream<SyncState>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncState SyncState
no setter

Methods

cancelRetry() → void
clearAllPendingMutations() Future<void>
clearPendingMutation(String requestId) Future<void>
clearSyncErrors() → void
dispose() Future<void>
ensureInitialized() Future<void>
getPendingMutations() Future<List<PendingMutation>>
loadFromOfflineCache() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMutationDropped(PendingMutation mutation, String reason) Future<void>
override
onMutationQueued(String requestId, List<OptimisticChange>? changes) → void
override
onOptimisticChanges(String requestId, List<OptimisticChange>? changes) → void
override
onRollbackOptimistic(String requestId) → void
override
persistTableSnapshots({Set<String>? onlyTables}) Future<void>
resetRetryAttempts() → void
syncPendingMutations() Future<void>
toString() String
A string representation of this object.
inherited
trySyncNow() → void
override
updatePendingCount() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited