OptimisticStateManager class

Constructors

OptimisticStateManager(ClientCache _cache)

Properties

activeRequestIds Set<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyOptimisticChanges(String requestId, List<OptimisticChange>? changes) → void
clear() → void
clearConfirmedOverlay(String requestId) → void
clearNonOptimisticRows(String tableName) → void
confirmOptimisticChange(String requestId) List<OptimisticEntry>
confirmOrRollbackWithTouchedKeys(String requestId, Map<String, Set> touchedKeysByTable) → void
hasOptimisticChange(String requestId) bool
hasPendingEntryForKey(String tableName, dynamic primaryKey) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimisticInsertRowsForTable(String tableName) List<Map<String, dynamic>>
optimisticNoPkInsertRequestIdsForTable(String tableName) Set<String>
optimisticPkInsertRowsForTable(String tableName) List<Map<String, dynamic>>
optimisticPrimaryKeysForTable(String tableName) Set
rollbackOptimisticChanges(String requestId) Set<String>
stashCommittedState(String tableName, dynamic primaryKey, Map<String, dynamic>? committedRowJson) → void
toString() String
A string representation of this object.
inherited
wasOverlayConfirmedForKey(String requestId, String tableName, dynamic primaryKey) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited