PendingMutation class
Constructors
-
PendingMutation({required String requestId, required String reducerName, required Uint8List encodedArgs, required DateTime createdAt, List<
OptimisticChange> ? optimisticChanges}) -
PendingMutation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → DateTime
-
final
- encodedArgs → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
optimisticChanges
→ List<
OptimisticChange> ? -
final
- reducerName → String
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? requestId, String? reducerName, Uint8List? encodedArgs, DateTime? createdAt, List< OptimisticChange> ? optimisticChanges}) → PendingMutation -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited