ReducerRegistry class

Constructors

ReducerRegistry()

Properties

count int
no setter
hashCode int
The hash code for this object.
no setterinherited
registeredReducers List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deserializeArgs(String reducerName, Uint8List bytes) → dynamic
hasDecoder(String reducerName) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register<A>(ReducerDef<A> def) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited