CallReducerMessage class

v2 CallReducer. Wire: v2.rs:115-131. { request_id: u32, flags: CallReducerFlags(u8), reducer: Box<str>, args: Bytes }.

Implemented types

Constructors

CallReducerMessage({required String reducerName, required Uint8List args, int requestId = 0})

Properties

args Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
messageType ClientMessageType
no setteroverride
reducerName String
final
requestId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Uint8List
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited