ClientMessageType enum
v2 ClientMessage tag order (v2.rs:18-29).
Values
- subscribe → const ClientMessageType
-
const ClientMessageType(0) - unsubscribe → const ClientMessageType
-
const ClientMessageType(1) - oneOffQuery → const ClientMessageType
-
const ClientMessageType(2) - callReducer → const ClientMessageType
-
const ClientMessageType(3) - callProcedure → const ClientMessageType
-
const ClientMessageType(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ClientMessageType> - A constant List of the values in this enum, in order of their declaration.