ConnectionQuality class
Constructors
- ConnectionQuality({required ConnectionState status, int reconnectAttempts = 0, Duration? timeSinceLastConnection, Duration? averageLatency, String? lastError, DateTime? lastPingSent, DateTime? lastPongReceived})
Properties
- averageLatency → Duration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthScore → double
-
no setter
- lastError → String?
-
final
- lastPingSent → DateTime?
-
final
- lastPongReceived → DateTime?
-
final
- qualityDescription → String
-
no setter
- reconnectAttempts → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ConnectionState
-
final
- timeSinceLastConnection → Duration?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited