ConnectionState class sealed

Implementers

Properties

canRetry bool
no setter
displayName String
no setter
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
isConnecting bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited