Disconnected class

Inheritance

Constructors

Disconnected()
const

Properties

canRetry bool
no setterinherited
displayName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setterinherited
isConnecting bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited