InMemoryOfflineStorage class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → Future< void> -
override
-
clearMutationQueue(
) → Future< void> -
override
-
clearTableSnapshot(
String tableName) → Future< void> -
override
-
dequeueMutation(
String requestId) → Future< void> -
override
-
dispose(
) → Future< void> -
override
-
enqueueMutation(
PendingMutation mutation) → Future< void> -
override
-
getLastSyncTime(
String tableName) → Future< DateTime?> -
override
-
getPendingMutations(
) → Future< List< PendingMutation> > -
override
-
initialize(
) → Future< void> -
override
-
loadTableSnapshot(
String tableName) → Future< List< Map< ?>String, dynamic> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveTableSnapshot(
String tableName, List< Map< rows) → Future<String, dynamic> >void> -
override
-
setLastSyncTime(
String tableName, DateTime time) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited