MutationSyncResult class

Constructors

MutationSyncResult({required String requestId, required String reducerName, required bool success, String? error, bool expired = false, List<OptimisticChange>? optimisticChanges})
const

Properties

error String?
final
expired bool
final
hashCode int
The hash code for this object.
no setterinherited
optimisticChanges List<OptimisticChange>?
final
reducerName String
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited