OfflineStorage class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → Future< void> -
clearMutationQueue(
) → Future< void> -
clearTableSnapshot(
String tableName) → Future< void> -
dequeueMutation(
String requestId) → Future< void> -
dispose(
) → Future< void> -
enqueueMutation(
PendingMutation mutation) → Future< void> -
getLastSyncTime(
String tableName) → Future< DateTime?> -
getPendingMutations(
) → Future< List< PendingMutation> > -
initialize(
) → Future< void> -
loadTableSnapshot(
String tableName) → Future< List< Map< ?>String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveTableSnapshot(
String tableName, List< Map< rows) → Future<String, dynamic> >void> -
setLastSyncTime(
String tableName, DateTime time) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited