OneOffQueryMessage class
v2 OneOffQuery. Wire: v2.rs:101-109.
{ request_id: u32, query_string: Box<str> }.
- Implemented types
Constructors
- OneOffQueryMessage({required String queryString, int requestId = 0})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageType → ClientMessageType
-
no setteroverride
- queryString → String
-
final
- requestId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Uint8List -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited