OneOffQueryResponse class

One-off query response from server

Implemented types

Constructors

OneOffQueryResponse({required Uint8List messageId, required int requestId, required List<OneOffTable> tables, required Int64 totalHostExecutionDurationMicros, String? error})

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
messageId Uint8List
final
messageType ServerMessageType
no setteroverride
requestId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tables List<OneOffTable>
final
totalHostExecutionDurationMicros Int64
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) OneOffQueryResponse