OneOffQueryResult class

v2 OneOffQueryResult. Wire: v2.rs:358-367{ request_id: u32, result: Result<QueryRows, Box<str>> }. Result<T,E> sum: tag 0 = Ok, tag 1 = Err (verified sats/ser/impls.rs:120-123).

Implemented types

Constructors

OneOffQueryResult({required int requestId, QueryRows? rows, String? error})

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
messageType ServerMessageType
no setteroverride
requestId int
final
rows QueryRows?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) OneOffQueryResult