PersistentTableRows class

Inheritance

Constructors

PersistentTableRows({required BsatnRowList inserts, required BsatnRowList deletes})
const

Properties

deletes BsatnRowList
final
hashCode int
The hash code for this object.
no setterinherited
inserts BsatnRowList
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) PersistentTableRows
override