ProcedureStatus class

v2 ProcedureStatus two-variant sum. Wire: tag 0 Returned(Bytes) — u32 length + bytes; tag 1 InternalError(Box<str>). Front-loaded to slice 2 (was a v1-shape collision with unit OutOfEnergy at tag 1).

Constructors

ProcedureStatus({required ProcedureStatusType type, Uint8List? returnedData, String? errorMessage})

Properties

errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
returnedData Uint8List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ProcedureStatusType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) ProcedureStatus