QueryRows class

Flat rows-per-table container used by SubscribeApplied / UnsubscribeApplied / OneOffQueryResult. Wire: v2.rs:223-237.

Constructors

QueryRows({required List<SingleTableRows> tables})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tables List<SingleTableRows>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) QueryRows