ScheduleAtTime class

Inheritance

Constructors

ScheduleAtTime(Int64 microsSinceUnixEpoch)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
microsSinceUnixEpoch Int64
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encodeBsatn(BsatnEncoder encoder) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override