ServerMessageType enum

Server message type tags (Server -> Client). Based on v2 websocket.rs ServerMessage enum order (v2.rs:175-196).

Inheritance
Available extensions

Values

initialConnection → const ServerMessageType
const ServerMessageType(0)
subscribeApplied → const ServerMessageType
const ServerMessageType(1)
unsubscribeApplied → const ServerMessageType
const ServerMessageType(2)
subscriptionError → const ServerMessageType
const ServerMessageType(3)
transactionUpdate → const ServerMessageType
const ServerMessageType(4)
oneOffQueryResult → const ServerMessageType
const ServerMessageType(5)
reducerResult → const ServerMessageType
const ServerMessageType(6)
procedureResult → const ServerMessageType
const ServerMessageType(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromTag(int tag) ServerMessageType

Constants

values → const List<ServerMessageType>
A constant List of the values in this enum, in order of their declaration.