SubscribeApplied class
v2 SubscribeApplied — initial-data delivery for a query set.
Wire: v2.rs:206-221 — { request_id: u32, query_set_id: u32, rows: QueryRows }.
- Implemented types
Constructors
- SubscribeApplied({required int requestId, required int querySetId, required QueryRows rows})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageType → ServerMessageType
-
no setteroverride
- querySetId → int
-
final
- requestId → int
-
final
- rows → QueryRows
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
BsatnDecoder decoder) → SubscribeApplied