SubscribeMessage class

v2 Subscribe. Wire: v2.rs:53-67. { request_id: u32, query_set_id: u32, query_strings: Box<[Box<str>]> }.

Implemented types

Constructors

SubscribeMessage(List<String> queries, {required int querySetId, int requestId = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
messageType ClientMessageType
no setteroverride
queries List<String>
final
querySetId int
final
requestId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Uint8List
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited