SubscriptionErrorMessage class

v2 SubscriptionError. Wire: v2.rs:271-291{ request_id: Option<u32>, query_set_id: QuerySetId, error: Box<str> }.

Implemented types

Constructors

SubscriptionErrorMessage({required int? requestId, required int querySetId, required String error})

Properties

error String
final
hashCode int
The hash code for this object.
no setterinherited
messageType ServerMessageType
no setteroverride
querySetId int
final
requestId int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) SubscriptionErrorMessage