iter method
Returns an iterable of all rows in the cache
Example:
for (final note in noteTable.iter()) {
print('${note.id}. ${note.title}');
}
Implementation
Iterable<T> iter() {
return hasPrimaryKey ? _rowsByPrimaryKey.values : _rows;
}
Returns an iterable of all rows in the cache
Example:
for (final note in noteTable.iter()) {
print('${note.id}. ${note.title}');
}
Iterable<T> iter() {
return hasPrimaryKey ? _rowsByPrimaryKey.values : _rows;
}