TableEventSpec class
Constructors
- TableEventSpec.delete(Object? row)
-
const
- TableEventSpec.insert(Object? row)
-
const
- TableEventSpec.update(Object? oldRow, Object? newRow)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → TableEventKind
-
final
- newRow → Object?
-
final
- oldRow → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited