TableUpdate class

Table update — v2 wire shape per v2.rs:316-321. { table_name: RawIdentifier, rows: Box<[TableUpdateRows]> }

Constructors

TableUpdate({required String tableName, required List<TableUpdateRows> rows})

Properties

hashCode int
The hash code for this object.
no setterinherited
rows List<TableUpdateRows>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) TableUpdate