TransactionUpdateMessage class

v2 TransactionUpdate — non-caller broadcast. Wire: v2.rs:302-306{ query_sets: Box<[QuerySetUpdate]> }.

Implemented types

Constructors

TransactionUpdateMessage({required List<QuerySetUpdate> querySets})

Properties

hashCode int
The hash code for this object.
no setterinherited
messageType ServerMessageType
no setteroverride
querySets List<QuerySetUpdate>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) TransactionUpdateMessage