UpdateStatus class sealed

Status of a reducer transaction.

Wire: v2 ReducerOutcome (v2.rs:385-406) — decoded in slice 4 via ReducerResult. Pending/Dropped are SDK-synthetic (offline queue).

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited