OptimisticEntry class

Constructors

OptimisticEntry({required String tableName, required OptimisticChangeType type, required dynamic primaryKey, Map<String, dynamic>? oldRowJson, Map<String, dynamic>? newRowJson})

Properties

hashCode int
The hash code for this object.
no setterinherited
newRowJson Map<String, dynamic>?
final
oldRowJson Map<String, dynamic>?
final
primaryKey → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
final
type OptimisticChangeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited