OptimisticStateManager class

Constructors

OptimisticStateManager(ClientCache _cache)

Properties

activeRequestIds Set<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyOptimisticChanges(String requestId, List<OptimisticChange>? changes) → void
clear() → void
clearNonOptimisticRows(String tableName) → void
confirmOptimisticChange(String requestId) → void
confirmOrRollbackWithTouchedKeys(String requestId, Map<String, Set> touchedKeysByTable) → void
hasOptimisticChange(String requestId) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimisticPrimaryKeysForTable(String tableName) Set
rollbackOptimisticChanges(String requestId) Set<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited