ReducerEmitter class
Constructors
Properties
-
activeReducers
→ List<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
emit(
String reducerName, EventContext context) → void -
hasListeners(
String reducerName) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on<
A> (ReducerDef< A> def) → Stream<EventContext> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited