RowDecoder<T> class
abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPrimaryKey → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsJsonSerialization → bool
-
no setter
Methods
-
decode(
BsatnDecoder decoder) → T -
fromJson(
Map< String, dynamic> json) → T? -
getPrimaryKey(
T row) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
T row) → Map< String, dynamic> ? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited