SubscriptionManager class
Constructors
- SubscriptionManager(SpacetimeDbConnection _connection, {OfflineStorage? offlineStorage})
Properties
-
activeSubscriptionQueries
→ Set<
String> -
no setter
- address → String?
-
no setter
- cache → ClientCache
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasOfflineStorage → bool
-
no setter
- identity → Identity?
-
no setter
-
onIdentityToken
→ Stream<
IdentityTokenMessage> -
no setter
-
onInitialSubscription
→ Stream<
InitialSubscriptionMessage> -
no setter
-
onMutationSyncResult
→ Stream<
MutationSyncResult> -
no setter
-
onOneOffQueryResponse
→ Stream<
OneOffQueryResponse> -
no setter
-
onProcedureResult
→ Stream<
ProcedureResultMessage> -
no setter
-
onSubscribeApplied
→ Stream<
SubscribeApplied> -
no setter
-
onSubscribeMultiApplied
→ Stream<
SubscribeMultiApplied> -
no setter
-
onSubscriptionError
→ Stream<
SubscriptionErrorMessage> -
no setter
-
onSyncStateChanged
→ Stream<
SyncState> -
no setter
-
onTransactionUpdate
→ Stream<
TransactionUpdateMessage> -
no setter
-
onTransactionUpdateLight
→ Stream<
TransactionUpdateLightMessage> -
no setter
-
onUnsubscribeApplied
→ Stream<
UnsubscribeApplied> -
no setter
-
onUnsubscribeMultiApplied
→ Stream<
UnsubscribeMultiApplied> -
no setter
- reducerEmitter → ReducerEmitter
-
final
- reducerRegistry → ReducerRegistry
-
final
- reducers ↔ ReducerCaller
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syncState → SyncState
-
no setter
Methods
-
callProcedure(
String procedureName, Uint8List args, {int requestId = 0}) → void -
clearAllPendingMutations(
) → Future< void> -
clearPendingMutation(
String requestId) → Future< void> -
dispose(
) → Future< void> -
getPendingMutations(
) → Future< List< PendingMutation> > -
loadFromOfflineCache(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
oneOffQuery(
Uint8List messageId, String query) → void -
subscribe(
List< String> queries) → Future<void> -
subscribeMulti(
List< String> queries, {int requestId = 0, int queryId = 0}) → void -
subscribeSingle(
String query, {int requestId = 0, int queryId = 0}) → void -
syncPendingMutations(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
int queryId, {int requestId = 0}) → void -
unsubscribeMulti(
int queryId, {int requestId = 0}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited