InitialConnectionMessage class
v2 InitialConnection — handshake payload.
Wire: v2.rs:198-204 — { identity, connection_id, token }.
- Implemented types
Constructors
- InitialConnectionMessage({required Uint8List identity, required Uint8List connectionId, required String token})
Properties
- connectionId → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity → Uint8List
-
final
- messageType → ServerMessageType
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
BsatnDecoder decoder) → InitialConnectionMessage