ProcedureResultMessage class
v2 ProcedureResult — procedure invocation outcome.
- Implemented types
Constructors
- ProcedureResultMessage({required ProcedureStatus status, required Int64 timestamp, required Int64 totalHostExecutionDurationMicros, required int requestId})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageType → ServerMessageType
-
no setteroverride
- requestId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ProcedureStatus
-
final
- timestamp → Int64
-
final
- totalHostExecutionDurationMicros → Int64
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
BsatnDecoder decoder) → ProcedureResultMessage