QuerySetUpdate class
A set of TableUpdates scoped to a client-assigned QuerySetId.
Wire: v2.rs:308-314.
Constructors
-
QuerySetUpdate({required int querySetId, required List<
TableUpdate> tables})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- querySetId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tables
→ List<
TableUpdate> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
BsatnDecoder decoder) → QuerySetUpdate