ReducerResultMessage class
v2 ReducerResult — caller's CallReducer outcome.
Wire: v2.rs:371-381 — { request_id: u32, timestamp: Timestamp(i64 µs), result: ReducerOutcome }.
Timestamp on v2 wire is microseconds (canonical sats/src/timestamp.rs:11-14,
stale v2.rs:378 doc comment notwithstanding).
- Implemented types
Constructors
-
ReducerResultMessage({required int requestId, required Int64 timestamp, required UpdateStatus status, required List<
QuerySetUpdate> querySets, Uint8List? retValue})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageType → ServerMessageType
-
no setteroverride
-
querySets
→ List<
QuerySetUpdate> -
final
- requestId → int
-
final
- retValue → Uint8List?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → UpdateStatus
-
final
- timestamp → Int64
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
BsatnDecoder decoder) → ReducerResultMessage