ServerMessageType enum

Server message type tags (Server -> Client) Based on websocket.rs ServerMessage enum order

Inheritance
Available extensions

Values

initialSubscription → const ServerMessageType
const ServerMessageType(0)
transactionUpdate → const ServerMessageType
const ServerMessageType(1)
transactionUpdateLight → const ServerMessageType
const ServerMessageType(2)
identityToken → const ServerMessageType
const ServerMessageType(3)
oneOffQueryResponse → const ServerMessageType
const ServerMessageType(4)
subscribeApplied → const ServerMessageType
const ServerMessageType(5)
unsubscribeApplied → const ServerMessageType
const ServerMessageType(6)
subscriptionError → const ServerMessageType
const ServerMessageType(7)
subscribeMultiApplied → const ServerMessageType
const ServerMessageType(8)
unsubscribeMultiApplied → const ServerMessageType
const ServerMessageType(9)
procedureResult → const ServerMessageType
const ServerMessageType(10)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromTag(int tag) ServerMessageType

Constants

values → const List<ServerMessageType>
A constant List of the values in this enum, in order of their declaration.