SpacetimeDbConnection class
Constructors
- SpacetimeDbConnection({required String host, required String database, String? initialToken, bool ssl = false, ConnectionConfig config = const ConnectionConfig(), WebSocketFactory? socketFactory})
Properties
- config → ConnectionConfig
-
final
-
connectionQuality
→ Stream<
ConnectionQuality> -
no setter
- database → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
final
- initialToken → String?
-
final
- isConnected → bool
-
no setter
- negotiatedProtocol → NegotiatedWsProtocol
-
no setter
-
onError
→ Stream<
String> -
no setter
-
onMessage
→ Stream<
Uint8List> -
no setter
-
onStateChanged
→ Stream<
ConnectionState> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssl → bool
-
final
- state → ConnectionState
-
no setter
- token → String?
-
no setter
Methods
-
callReducer(
String reducerName, Uint8List args, {int? requestId}) → Future< void> -
connect(
) → Future< void> -
disconnect(
) → Future< void> -
dispose(
) → Future< void> -
enableAutoReconnect(
bool enabled) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reconnect(
) → Future< void> -
retryConnection(
) → Future< void> -
send(
Uint8List data) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateToken(
String token) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited