SubscriptionErrorMessage class

Subscription error from server

Implemented types

Constructors

SubscriptionErrorMessage({required Int64 totalHostExecutionDurationMicros, required int requestId, required int queryId, required int tableId, required String error})

Properties

error String
final
hashCode int
The hash code for this object.
no setterinherited
messageType ServerMessageType
no setteroverride
queryId int
final
requestId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableId int
final
totalHostExecutionDurationMicros Int64
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) SubscriptionErrorMessage