SyncState class
Constructors
-
SyncState({SyncStatus status = SyncStatus.idle, int pendingCount = 0, String? lastError, DateTime? lastSyncTime, int failedCount = 0, List<
MutationSyncResult> recentFailures = const []}) -
const
Properties
- failedCount → int
-
final
- hasError → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPending → bool
-
no setter
- isIdle → bool
-
no setter
- isSyncing → bool
-
no setter
- lastError → String?
-
final
- lastSyncTime → DateTime?
-
final
- pendingCount → int
-
final
-
recentFailures
→ List<
MutationSyncResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → SyncStatus
-
final
Methods
-
copyWith(
{SyncStatus? status, int? pendingCount, String? lastError, DateTime? lastSyncTime, int? failedCount, List< MutationSyncResult> ? recentFailures}) → SyncState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited