TableDeleteEvent<T> class
Event emitted when a row is deleted from a table
Contains the deleted row and the event context with transaction metadata.
Example:
noteTable.deleteEventStream.listen((event) {
print('Note deleted: ${event.row.title}');
if (event.context.isMyTransaction) {
print('I deleted this note');
} else {
print('Someone else deleted this note');
}
});
- Inheritance
-
- Object
- TableEvent<
T> - TableDeleteEvent
Constructors
- TableDeleteEvent(EventContext context, T row)
Properties
- context → EventContext
-
Context containing the Event and client access
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- row → T
-
The deleted row (contains data before deletion)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited