TableUpdate class

Table update matching the actual protocol structure

Constructors

TableUpdate({required int tableId, required String tableName, required Int64 numRows, required List<CompressableQueryUpdate> updates})

Properties

hashCode int
The hash code for this object.
no setterinherited
numRows Int64
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableId int
final
tableName String
final
updates List<CompressableQueryUpdate>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) TableUpdate