TransactionBatch<T> class
Constructors
-
TransactionBatch(EventContext context, List<
TableEvent< events)T> >
Properties
- context → EventContext
-
final
-
deletes
→ Iterable<
TableDeleteEvent< T> > -
no setter
-
events
→ List<
TableEvent< T> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inserts
→ Iterable<
TableInsertEvent< T> > -
no setter
- isEmpty → bool
-
no setter
- isNotEmpty → bool
-
no setter
- length → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
updates
→ Iterable<
TableUpdateEvent< T> > -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited