TransactionUpdateLightMessage class
Lightweight transaction update with minimal metadata
- Implemented types
Constructors
-
TransactionUpdateLightMessage({required int requestId, required List<
TableUpdate> tableUpdates})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageType → ServerMessageType
-
no setteroverride
- requestId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tableUpdates
→ List<
TableUpdate> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
BsatnDecoder decoder) → TransactionUpdateLightMessage