TransactionUpdateMessage class

Implemented types

Constructors

TransactionUpdateMessage({required int transactionOffset, required Int64 timestamp, required List<TableUpdate> tableUpdates, required UpdateStatus status, required Uint8List callerIdentity, required Uint8List callerConnectionId, required ReducerInfo reducerCall, required int energyQuantaUsed, required Int64 totalHostExecutionDuration})

Properties

callerConnectionId Uint8List
final
callerIdentity Uint8List
final
energyQuantaUsed int
final
hashCode int
The hash code for this object.
no setterinherited
messageType ServerMessageType
no setteroverride
reducerCall ReducerInfo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status UpdateStatus
final
tableUpdates List<TableUpdate>
final
timestamp Int64
final
totalHostExecutionDuration Int64
final
transactionOffset int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(BsatnDecoder decoder) TransactionUpdateMessage