UnsubscribeApplied class
v2 UnsubscribeApplied.
Wire: v2.rs:245-254 — { request_id: u32, query_set_id: u32, rows: Option<QueryRows> }.
rows populated only when the matching Unsubscribe set SendDroppedRows.
- Implemented types
Constructors
- UnsubscribeApplied({required int requestId, required int querySetId, QueryRows? rows})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageType → ServerMessageType
-
no setteroverride
- querySetId → int
-
final
- requestId → int
-
final
- rows → QueryRows?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
BsatnDecoder decoder) → UnsubscribeApplied