UnsubscribeMessage class
v2 Unsubscribe. Wire: v2.rs:74-93.
{ request_id: u32, query_set_id: u32, flags: UnsubscribeFlags(u8) }.
- Implemented types
Constructors
- UnsubscribeMessage({required int querySetId, int requestId = 0, UnsubscribeFlags flags = UnsubscribeFlags.defaultFlag})
Properties
- flags → UnsubscribeFlags
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageType → ClientMessageType
-
no setteroverride
- querySetId → int
-
final
- requestId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Uint8List -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited